==> newlife-components-1.4.20.tgz: package/src/lib/router/index.js <==
import Router from 'vue-router'
import sys_routers from './routers'
import UtilNotEmpty from "../../utils/js/UtilNotEmpty";
import UtilEmpty from "../../utils/js/UtilEmpty";
// 解决ElementUI导航NavigationDuplicated
const originalPush = Router.prototype.push;
Router.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
};

export default class NfRouter {
  constructor() {
    throw "NfRouter为单例模式请使用init或instance获取实例";
  }

  static init(childRouters, Vue) {
    if (!this.instance) {
      let routerModules = [];
      let loginRouter = null;
      let mainRouter = null;
      if (UtilNotEmpty.obj(childRouters)) {
        loginRouter = childRouters.login;
        mainRouter = childRouters.main;
      }
      if (UtilEmpty.obj(loginRouter)) {
        console.info("未配置login路由，系统设置为默认");
        loginRouter = sys_routers.login;
      }
      if (UtilEmpty.obj(mainRouter)) {
        console.info("未配置main路由，系统设置为默认");
        mainRouter = sys_routers.main;
      }
      routerModules.push(loginRouter, mainRouter);
      let vueRouter = new Router({
        mode: 'history',
        routes: routerModules
      });
      this.nfPathLogin = loginRouter['path'];
      this.nfPathMain = mainRouter['path'];
      Vue.prototype.$nfPathLogin = loginRouter['path'];
      Vue.prototype.$nfPathMain = mainRouter['path'];
      vueRouter.beforeEach((to, from, next) => {
        //不存在的路由直接跳转到登录页
        let curPath = to.path;
        if (to.matched.length === 0) {
          curPath = loginRouter['path'];
          next(curPath);
        } else {
          //判断是否需要登录
          if (to.meta['needToken'] === true) {
            let token = Vue.prototype.$nfStore.getters.loginToken;
            if (UtilNotEmpty.obj(token) && UtilNotEmpty.string(token['access_token'])) {
              next();
            } else {
              curPath = loginRouter['path'];
              next(curPath);
            }
          } else {
            next();
          }
        }
        //记录当前的router-path
        Vue.prototype.$nfStore.commit("setRouterPath", curPath);
      });
      this.instance = vueRouter;
    }
    return this.instance;
  }
}

==> newlife-components-1.5.16.tgz: package/src/lib/router/index.js <==
import Router from 'vue-router'
import sys_routers from './routers'
import UtilNotEmpty from "../../utils/js/UtilNotEmpty";
import UtilEmpty from "../../utils/js/UtilEmpty";
// 解决ElementUI导航NavigationDuplicated
const originalPush = Router.prototype.push;
Router.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
};

export default class NfRouter {
  constructor() {
    throw "NfRouter为单例模式请使用init或instance获取实例";
  }

  static init(childRouters, Vue) {
    if (!this.instance) {
      let routerModules = [];
      let loginRouter = null;
      let mainRouter = null;
      if (UtilNotEmpty.obj(childRouters)) {
        loginRouter = childRouters.login;
        mainRouter = childRouters.main;
      }
      if (UtilEmpty.obj(loginRouter)) {
        console.info("未配置login路由，系统设置为默认");
        loginRouter = sys_routers.login;
      }
      if (UtilEmpty.obj(mainRouter)) {
        console.info("未配置main路由，系统设置为默认");
        mainRouter = sys_routers.main;
      }
      routerModules.push(loginRouter, mainRouter);
      let vueRouter = new Router({
        mode: 'history',
        routes: routerModules
      });
      // this.nfPathLogin = loginRouter['path'];
      // this.nfPathMain = mainRouter['path'];
      Vue.prototype.$nfPathLogin = loginRouter['path'];
      Vue.prototype.$nfPathMain = mainRouter['path'];
      vueRouter.beforeEach((to, from, next) => {
        //不存在的路由直接跳转到登录页
        let curPath = to.path;
        if (to.matched.length === 0) {
          curPath = loginRouter['path'];
          next(curPath);
        } else {
          //判断是否需要登录
          if (to.meta['needToken'] === true) {
            let token = Vue.prototype.$nfStore.getters.loginToken;
            if (UtilNotEmpty.obj(token) && UtilNotEmpty.string(token['access_token'])) {
              next();
            } else {
              console.info("未找到登录信息");
              curPath = loginRouter['path'];
              next(curPath);
            }
          } else {
            next();
          }
        }
        //记录当前的router-path
        Vue.prototype.$nfStore.commit("setRouterPath", curPath);
      });
      this.instance = vueRouter;
    }
    return this.instance;
  }
}
